==> wordpress-1.5.1-da_DK.tar.gz: wordpress/wp-content/themes/default/archive.php <==
﻿<?php get_header(); ?>

	<div id="content" class="narrowcolumn">

		<?php if (have_posts()) : ?>

		 <?php $post = $posts[0]; // Hack. Sørger for at the_date() virker i $post. ?>
 	  <?php /* Hvis dette er et kategori-arkiv */ if (is_category()) { ?>				
		<h2 class="pagetitle">Arkiv for kategorien '<?php echo single_cat_title(); ?>'</h2>
		
 	  <?php /* Hvis dette er et dagligt arkiv */ } elseif (is_day()) { ?>
		<h2 class="pagetitle">Arkiv for <?php the_time('F jS, Y'); ?></h2>
		
	 <?php /* Hvis dette er et månedligt arkiv */ } elseif (is_month()) { ?>
		<h2 class="pagetitle">Arkiv for <?php the_time('F, Y'); ?></h2>

		<?php /* Hvis dette er et årligt arkiv */ } elseif (is_year()) { ?>
		<h2 class="pagetitle">Arkiv for <?php the_time('Y'); ?></h2>
		
	  <?php /* Hvis dette er en søgning */ } elseif (is_search()) { ?>
		<h2 class="pagetitle">S&oslash;geresultater</h2>
		
	  <?php /* Hvis dette er et forfatter-arkiv */ } elseif (is_author()) { ?>
		<h2 class="pagetitle">Forfatter-arkiv</h2>

		<?php /* Hvis dette er en arkivside */ } elseif (isset($_GET['paged']) && !empty($_GET['paged'])) { ?>
		<h2 class="pagetitle">Blog-arkiver</h2>

		<?php } ?>


		<div class="navigation">
			<div class="alignleft"><?php next_posts_link('&laquo; Tidligere indl&aelig;g') ?></div>
			<div class="alignright"><?php previous_posts_link('Senere indl&aelig;g &raquo;') ?></div>
		</div>

		<?php while (have_posts()) : the_post(); ?>
		<div class="post">
				<h3 id="post-<?php the_ID(); ?>"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent link til <?php the_title(); ?>"><?php the_title(); ?></a></h3>
				<small><?php the_time('l, j. F Y') ?></small>
				
				<div class="entry">
					<?php the_excerpt() ?>
				</div>
		
				<p class="postmetadata">Gemt i <?php the_category(', ') ?> <strong>|</strong> <?php edit_post_link('Rediger','','<strong>|</strong>'); ?>  <?php comments_popup_link('Ingen kommentarer &#187;', '1 kommentar &#187;', '% kommentarer &#187;'); ?></p> 

			</div>
	
		<?php endwhile; ?>

		<div class="navigation">
			<div class="alignleft"><?php next_posts_link('&laquo; Tidligere indl&aelig;g') ?></div>
			<div class="alignright"><?php previous_posts_link('Senere indl&aelig;g &raquo;') ?></div>
		</div>
	
	<?php else : ?>

		<h2 class="center">Ikke fundet</h2>
		<?php include (TEMPLATEPATH . '/searchform.php'); ?>

	<?php endif; ?>
		
	</div>

<?php get_sidebar(); ?>

<?php get_footer(); ?>

==> wordpress-1.5.1.2-da_DK.tar.gz: wordpress/wp-content/themes/default/archive.php <==
<?php get_header(); ?>

	<div id="content" class="narrowcolumn">

		<?php if (have_posts()) : ?>

		 <?php $post = $posts[0]; // Hack. Srger for at the_date() virker i $post. ?>
 	  <?php /* Hvis dette er et kategori-arkiv */ if (is_category()) { ?>				
		<h2 class="pagetitle">Arkiv for kategorien '<?php echo single_cat_title(); ?>'</h2>
		
 	  <?php /* Hvis dette er et dagligt arkiv */ } elseif (is_day()) { ?>
		<h2 class="pagetitle">Arkiv for <?php the_time('F jS, Y'); ?></h2>
		
	 <?php /* Hvis dette er et mnedligt arkiv */ } elseif (is_month()) { ?>
		<h2 class="pagetitle">Arkiv for <?php the_time('F, Y'); ?></h2>

		<?php /* Hvis dette er et rligt arkiv */ } elseif (is_year()) { ?>
		<h2 class="pagetitle">Arkiv for <?php the_time('Y'); ?></h2>
		
	  <?php /* Hvis dette er en sgning */ } elseif (is_search()) { ?>
		<h2 class="pagetitle">S&oslash;geresultater</h2>
		
	  <?php /* Hvis dette er et forfatter-arkiv */ } elseif (is_author()) { ?>
		<h2 class="pagetitle">Forfatter-arkiv</h2>

		<?php /* Hvis dette er en arkivside */ } elseif (isset($_GET['paged']) && !empty($_GET['paged'])) { ?>
		<h2 class="pagetitle">Blog-arkiver</h2>

		<?php } ?>


		<div class="navigation">
			<div class="alignleft"><?php next_posts_link('&laquo; Tidligere indl&aelig;g') ?></div>
			<div class="alignright"><?php previous_posts_link('Senere indl&aelig;g &raquo;') ?></div>
		</div>

		<?php while (have_posts()) : the_post(); ?>
		<div class="post">
				<h3 id="post-<?php the_ID(); ?>"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent link til <?php the_title(); ?>"><?php the_title(); ?></a></h3>
				<small><?php the_time('l, j. F Y') ?></small>
				
				<div class="entry">
					<?php the_excerpt() ?>
				</div>
		
				<p class="postmetadata">Gemt i <?php the_category(', ') ?> <strong>|</strong> <?php edit_post_link('Rediger','','<strong>|</strong>'); ?>  <?php comments_popup_link('Ingen kommentarer &#187;', '1 kommentar &#187;', '% kommentarer &#187;'); ?></p> 

			</div>
	
		<?php endwhile; ?>

		<div class="navigation">
			<div class="alignleft"><?php next_posts_link('&laquo; Tidligere indl&aelig;g') ?></div>
			<div class="alignright"><?php previous_posts_link('Senere indl&aelig;g &raquo;') ?></div>
		</div>
	
	<?php else : ?>

		<h2 class="center">Ikke fundet</h2>
		<?php include (TEMPLATEPATH . '/searchform.php'); ?>

	<?php endif; ?>
		
	</div>

<?php get_sidebar(); ?>

<?php get_footer(); ?>
